CompletionResponse class

Constructors

CompletionResponse({required String id, required String object, required int created, required String model, required List<Choices> choices, required Usage usage})
CompletionResponse.fromMap(Map<String, dynamic> map)
Create the object from a Map<String, dynamic>
factory

Properties

choices → List<Choices>
list of the values that brings the completion
final
created → int
date of the moment were the object was created
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
id of the object
final
model → String
model utilized to create the completion
final
object → String
type of the object
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usage → Usage
object that shows how much Tokens were spended on the request + response
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the object to a Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited