FineTunesResponse class

Constructors

FineTunesResponse(String id, String object, String model, int createdAt, List<Events?> events, String? fineTunedModel, Map<String, dynamic> hyperparams, String? organizationId, List resultFiles, String status, List validationFiles, List<TrainingFiles> trainingFiles, int? updatedAt)
FineTunesResponse.fromMap(Map<String, dynamic> map)
factory

Properties

createdAt int
final
events List<Events?>
final
fineTunedModel String?
final
hashCode int
The hash code for this object.
no setterinherited
hyperparams Map<String, dynamic>
final
id String
final
model String
final
object String
final
organizationId String?
final
resultFiles List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
trainingFiles List<TrainingFiles>
final
updatedAt int?
final
validationFiles List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited