FileData class

object that contains the info about the file

Constructors

FileData(String id, String object, int bytes, int createdAt, String filename, String purpose)
FileData.fromMap(Map<String, dynamic> map)
Create the object from a Map<String, dynamic>
factory

Properties

bytes → int
final
createdAt → int
final
filename → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
object → String
final
purpose → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the object to a Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited