Data class

Constructors

Data({String? id, String? objec, String? ownedBy})
Data.fromMap(Map<String, dynamic> map)
Create the object from a Map<String, dynamic>
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
id of the model used on the configs
final
objec → String?
type of object
final
ownedBy → String?
owner of the model
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the object to a Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited